@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use 5.008003;
 
-our $VERSION = '1.645';
+our $VERSION = '1.646';
 
 use Exporter qw( import );
 
@@ -19,8 +19,9 @@ our @EXPORT_OK = qw(
         RESET REVERSE UNDERLINE BOLD_UNDERLINE BEEP
         UP DOWN RIGHT LEFT
         NEXT_get_key
-        CONTROL_SPACE CONTROL_A CONTROL_B CONTROL_C CONTROL_D CONTROL_E CONTROL_F CONTROL_H KEY_BTAB CONTROL_I KEY_TAB
-        CONTROL_K KEY_ENTER CONTROL_U KEY_ESC KEY_SPACE KEY_h KEY_j KEY_k KEY_l KEY_q KEY_Tilde KEY_BSPACE
+        CONTROL_SPACE KEY_ENTER CONTROL_A CONTROL_B CONTROL_C CONTROL_D CONTROL_E CONTROL_F CONTROL_H
+        CONTROL_I CONTROL_K CONTROL_Q CONTROL_U CONTROL_X
+        KEY_BTAB KEY_TAB KEY_ESC KEY_SPACE KEY_h KEY_j KEY_k KEY_l KEY_q KEY_Tilde KEY_BSPACE
         VK_PAGE_UP VK_PAGE_DOWN VK_END VK_HOME VK_LEFT VK_UP VK_RIGHT VK_DOWN VK_INSERT VK_DELETE
         VK_CODE_PAGE_UP VK_CODE_PAGE_DOWN VK_CODE_END VK_CODE_HOME VK_CODE_LEFT VK_CODE_UP VK_CODE_RIGHT VK_CODE_DOWN
         VK_CODE_INSERT VK_CODE_DELETE
@@ -34,14 +35,14 @@ our %EXPORT_TAGS = (
         WIDTH_CURSOR
         MAX_ROW_MOUSE_1003 MAX_COL_MOUSE_1003
         NEXT_get_key
-        CONTROL_SPACE CONTROL_A CONTROL_B CONTROL_C CONTROL_D CONTROL_E CONTROL_F CONTROL_H KEY_BTAB CONTROL_I KEY_TAB
+        CONTROL_SPACE CONTROL_A CONTROL_B CONTROL_C CONTROL_E CONTROL_F CONTROL_H KEY_BTAB CONTROL_I CONTROL_Q KEY_TAB
         KEY_ENTER KEY_SPACE KEY_h KEY_j KEY_k KEY_l KEY_q KEY_Tilde KEY_BSPACE
         VK_PAGE_UP VK_PAGE_DOWN VK_END VK_HOME VK_LEFT VK_UP VK_RIGHT VK_DOWN VK_INSERT VK_DELETE
     ) ],
     form => [ qw(
         NEXT_get_key
-        CONTROL_A CONTROL_B CONTROL_D CONTROL_E CONTROL_F CONTROL_H KEY_BTAB KEY_TAB CONTROL_K CONTROL_U KEY_ENTER
-        KEY_SPACE KEY_h KEY_j KEY_k KEY_l KEY_BSPACE KEY_ESC
+        CONTROL_A CONTROL_B CONTROL_D CONTROL_E CONTROL_F CONTROL_H KEY_BTAB KEY_TAB CONTROL_K CONTROL_U CONTROL_X
+        KEY_ENTER KEY_SPACE KEY_h KEY_j KEY_k KEY_l KEY_BSPACE KEY_ESC
         VK_PAGE_UP VK_PAGE_DOWN VK_END VK_HOME VK_LEFT VK_UP VK_RIGHT VK_DOWN VK_INSERT VK_DELETE
     ) ],
     screen => [ qw(
@@ -130,7 +131,9 @@ use constant {
     KEY_TAB       => 0x09,
     CONTROL_K     => 0x0b,
     KEY_ENTER     => 0x0d,
+    CONTROL_Q     => 0x11,
     CONTROL_U     => 0x15,
+    CONTROL_X     => 0x18,
     KEY_ESC       => 0x1b,
     KEY_SPACE     => 0x20,
     KEY_h         => 0x68,
